/*******************************************************
 Author:					Manfred Langemann
 mailto:					Manfred.Langemann t t-online.de
 Begin of project:			21.11.2020
 Latest version generated:	12.12.2020
 Filename:					Commands.h
 Description:				Implementation of Command functions.
 *******************************************************/
#ifndef _COMMANDS
#define _COMMANDS
/*
** This is the enum list to be used, when the PC sends a command.
** This enum list MUST be identical with the one in the PC software.
*/
enum CommandsEEPROM_Tag
	{
	EEPROM_COMMAND_PING,					// Check programmer is alive
	EEPROM_COMMAND_WRITE_DATA,				// Send max 128 data bytes to be written to EEPROM, based on Intel hex file format
	EEPROM_COMMAND_READ_DATA,				// Send start to read up to 128 bytes from EEPROM
	EEPROM_COMMAND_ERASE,					// Send erase command
	EEPROM_RETURN_COMMAND_CONFIRMATION,		// The programmer confirms the command by returning this value in the iPara1 parameter
	EEPROM_RETURN_WRONG_COMMAND,			// The programmer has received a wrong command
	EEPROM_RETURN_ERROR,					// The programmer has detected an error in performing the command
	};
/*
** This is the Command and Data Byte (cdb) structure type definition.
*/
#define MAX_DATA_BYTES 128
typedef struct CommandDataBlock_Tag
	{
	uint8_t		iCommand;				// The command to send to the EEPROM Programmer, see above enum list
	uint8_t		iPara1;					// Optional: parameter 1
	uint8_t		iPara2;					// Optional: parameter 2
	uint8_t		iNumDataBytes;			// Optional: number of data bytes to be transmitted, 0 means no data bytes
	uint8_t		Data[MAX_DATA_BYTES];	// The data bytes to be transmitted
	} COMMAND_DATA_BLOCK;
/*
** Public Function Prototypes.
*/
void Commands_Init (void);
void Commands_Process (void);
uint8_t Commands_DoWriteToEEPROM (void);
uint8_t Commands_DoReadFromEEPROM (void);
uint8_t Commands_DoEraseEEPROM (void);

#endif
