/*******************************************************
 Author:					Manfred Langemann
 mailto:					Manfred.Langemann t t-online.de
 Begin of project:			21.11.2020
 Latest version generated:	12.12.2020
 Processor:					ATmega8
 Filename:					Programmer_Controller.c
 Description:				Main program for EEPROM Programmer Controller

 !!!!!!!!!!!!!!!!!!!!!!!!! WARNING !!!!!!!!!!!!!!!!!!!!!!!!!!
 Do not place any printf() statements to the code,
 because the content will be sent to the PC via the RS232 to USB line.
 But the PC does not understand this,
 because it only accepts data in form of binary command confirms and EEPROM data.
 !!!!!!!!!!!!!!!!!!!!!!!!! WARNING !!!!!!!!!!!!!!!!!!!!!!!!!!
 
 Important:
 ----------
 When the programmer only writes every second byte correctly to the EEPROM,
 then increase the delay time after the /WE pulse in function ProgProc_WriteByte() in file ProgProc.c

 Used Timers:
	TIMER0					: None
	TIMER1					: None
	TIMER2					: None

 Used Interrupts:			: None
	ISR (USART_RXC_vect)	: RS232.c		Serial link data reception
 *******************************************************/
#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <avr/io.h>
#include <avr/interrupt.h>			// necessary for cli() and sei() and interrupt functions

#include "General.h"
#include "Delay.h"
#include "RS232.h"
#include "Commands.h"
#include "ProgProc.h"

int main (void)
	{
/*
** Disable any interrupt until all elements are initiated.
*/
	cli ();
/*
** Power-on delay of 0.5 second.
*/
	Delay_ms (500);
/*
** Init RS232 Interface.
*/
	RS232_Init ();
/*
** Print Device Name and S/W Date and Time.
*/
	//printf ("Hello, I am EEPROM Programmer, ATmega8.\n");
	//printf ("S/W Version: %s %s\n", __DATE__, __TIME__);
/*
** Init the Programming and Command functions.
*/
	ProgProc_Init ();
	Commands_Init ();
/*
** Enable interrupt.
*/
	sei ();
/*
** Start the endless loop.
** When we have received a command from the PC via the RS232 link, then process it.
*/
	while (TRUE)
		{
		Commands_Process ();
		}
	}

